pybliometrics.scopus.ContentAffiliationRetrieval
================================================

.. currentmodule:: pybliometrics.scopus

.. autoclass:: ContentAffiliationRetrieval
   :members:
   :inherited-members:
